@@ -73,6 +73,8 @@ static void display_help_dialog       (BonoboUIComponent *uic,
 static void display_about_dialog      (BonoboUIComponent *uic,
 				       PagerData         *pager,
 				       const gchar       *verbname);
+static void set_tooltip               (GtkWidget         *applet);
+
 
 static void
 pager_update (PagerData *pager)
@@ -128,6 +130,47 @@ applet_change_orient (PanelApplet       *applet,
 		gtk_label_set_text(GTK_LABEL(pager->label_row_col), pager->orientation == GTK_ORIENTATION_HORIZONTAL ? _("Rows") : _("Columns"));	
 }
 
+static void 
+response_cb(GtkWidget * widget,int id, gpointer data)
+{
+	if(id == GTK_RESPONSE_HELP) {
+		
+		GError *error = NULL;
+		static GnomeProgram *applet_program = NULL;
+
+		if (!applet_program) {
+			int argc = 1;
+			char *argv[2] = { "workspace-switcher" };
+			applet_program = gnome_program_init ("workspace-switcher", VERSION,
+							     LIBGNOME_MODULE, argc, argv,
+							     GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
+		}
+
+		gnome_help_display_desktop (applet_program, "workspace-switcher",
+					    "workspace-switcher", "workspacelist-prefs", &error);
+		if (error) {
+			GtkWidget *dialog;
+			dialog = gtk_message_dialog_new (GTK_WINDOW(widget),
+							 GTK_DIALOG_DESTROY_WITH_PARENT,
+							 GTK_MESSAGE_ERROR,
+							 GTK_BUTTONS_CLOSE,
+							  _("There was an error displaying help: %s"),
+							 error->message);
+
+			g_signal_connect (G_OBJECT (dialog), "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  NULL);
+
+			gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+			gtk_widget_show (dialog);
+			g_error_free (error);
+
+		}
+
+	}
+	else
+		gtk_widget_hide (widget);
+}
 
 static void
 applet_change_pixel_size (PanelApplet *applet,
@@ -343,8 +386,7 @@ fill_pager_applet(PanelApplet *applet)
 		break;
 	}
 
-	/* TODO: Needs to get the screen number from DISPLAY or the panel. */
-	pager->screen = wnck_screen_get (0);
+	pager->screen = wnck_screen_get_default ();
 
 	/* because the pager doesn't respond to signals at the moment */
 	wnck_screen_force_update (pager->screen);
@@ -367,6 +409,8 @@ fill_pager_applet(PanelApplet *applet)
 	
 	gtk_container_add (GTK_CONTAINER (pager->applet), pager->frame);
 
+	set_tooltip (GTK_WIDGET (pager->applet));
+
 	gtk_widget_show (pager->applet);
 
 	g_signal_connect (G_OBJECT (pager->applet),
@@ -395,11 +439,35 @@ display_help_dialog (BonoboUIComponent *uic,
 		     const gchar       *verbname)
 {
 	GError *error = NULL;
+	static GnomeProgram *applet_program = NULL;
 
-	gnome_help_display_desktop (NULL, "workspace-switcher", "workspace-switcher", NULL, &error);
+	if (!applet_program) {
+		int argc = 1;
+		char *argv[2] = { "workspace-switcher" };
+		applet_program = gnome_program_init ("workspace-switcher", VERSION,
+						     LIBGNOME_MODULE, argc, argv,
+						     GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
+	}
+
+	gnome_help_display_desktop (applet_program, "workspace-switcher",
+				    "workspace-switcher", NULL, &error);
 	if (error) {
-		g_warning ("help error: %s\n", error->message);
+		GtkWidget *dialog;
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						  _("There was an error displaying help: %s"),
+						 error->message);
+
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
 		g_error_free (error);
+
 	}
 }
 
@@ -434,7 +502,7 @@ display_about_dialog (BonoboUIComponent *uic,
 
 	about = gnome_about_new (_("Workspace Switcher"), "1.0",
 				 _("(c) 2001 Red Hat, Inc."),
-				 _("The Workspace Switcher shows you a small version of your workspaces that lets you manage the windows."),
+				 _("The Workspace Switcher shows you a small version of your workspaces that lets you manage your windows."),
 				 authors,
 				 documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
@@ -497,7 +565,7 @@ update_workspaces_model (PagerData *pager)
 
 	gtk_list_store_clear (pager->workspaces_store);
 	for (i = 0; i < nr_ws; i++) {
-		workspace = wnck_workspace_get (i);
+		workspace = wnck_screen_get_workspace (pager->screen, i);
 		gtk_list_store_append (pager->workspaces_store, &iter);
 		gtk_list_store_set (pager->workspaces_store,
 				    &iter,
@@ -650,6 +718,9 @@ setup_dialog (GladeXML  *xml,
 	g_signal_connect (pager->properties_dialog, "delete_event",
 			  G_CALLBACK (delete_event),
 			  pager);
+	g_signal_connect (pager->properties_dialog, "response",
+			  G_CALLBACK (response_cb),
+			  pager);
 	
 	g_signal_connect_swapped (WID ("done_button"), "clicked",
 				  (GCallback) gtk_widget_hide, pager->properties_dialog);
@@ -678,7 +749,7 @@ setup_dialog (GladeXML  *xml,
 	
 	nr_ws = wnck_screen_get_workspace_count (pager->screen);
 	for (i = 0; i < nr_ws; i++) {
-		g_signal_connect (G_OBJECT (wnck_workspace_get (i)), "name_changed",
+		g_signal_connect (G_OBJECT (wnck_screen_get_workspace (pager->screen, i)), "name_changed",
 				  (GCallback) workspace_renamed, pager);
 	}
 }
@@ -704,3 +775,20 @@ display_properties_dialog (BonoboUIComponent *uic,
 
 	gtk_window_present (GTK_WINDOW (pager->properties_dialog));
 }
+
+/*
+ *Function to set tooltip
+ */
+static void
+set_tooltip (GtkWidget *applet)
+{
+	GtkTooltips *tooltips;
+
+	tooltips = gtk_tooltips_new ();
+	g_object_ref (tooltips);
+	gtk_object_sink (GTK_OBJECT (tooltips));
+	g_object_set_data_full (G_OBJECT (applet), "tooltips", tooltips,
+                                (GDestroyNotify) g_object_unref);
+        gtk_tooltips_set_tip (tooltips, applet,
+                              _("Workspace Switcher"), NULL);
+}
