@@ -44,7 +44,7 @@ panel_show_help (const char *doc_name, const char *linkid)
 {
 	GError *error = NULL;
 
-	if (!gnome_help_display_desktop (NULL, "panel", doc_name, linkid, &error)) {
+	if (!gnome_help_display_desktop (NULL, "user-guide", doc_name, linkid, &error)) {
 		panel_error_dialog ("cannot_show_help",
 				    _("<b>Cannot display help document</b>\n\n"
 				      "Details: %s"), error != NULL ? error->message : "");
@@ -1413,8 +1413,9 @@ panel_uri_exists (const char *uri)
 
 	suri = gnome_vfs_uri_new (uri);
 
-	/* eek */
-	g_return_val_if_fail (suri != NULL, FALSE);
+	if (!suri) {
+		return FALSE;
+	}
 
 	ret = gnome_vfs_uri_exists (suri);
 
